# colnade_dask

Dask backend adapter, construction functions, and I/O functions.

## DaskBackend

::: colnade_dask.adapter.DaskBackend

## Construction Functions

::: colnade_dask.io.from_dict

::: colnade_dask.io.from_rows

## I/O Functions

::: colnade_dask.io.scan_parquet

::: colnade_dask.io.scan_csv

::: colnade_dask.io.write_parquet

::: colnade_dask.io.write_csv
